@@ -167,9 +167,9 @@ class GRUFUserAtom(AccessControl.User.BasicUser, Implicit):
         ret = self._getGroups(no_recurse = 1)
         return list(ret)
     
-    def _getGroups(self, no_recurse = 0, already_done = [], prefix = GROUP_PREFIX):
+    def _getGroups(self, no_recurse = 0, already_done = None, prefix = GROUP_PREFIX):
         """
-        getGroups(self, no_recurse = 0, already_done = [], prefix = GROUP_PREFIX) => list of strings
+        getGroups(self, no_recurse = 0, already_done = None, prefix = GROUP_PREFIX) => list of strings
         
         If this user is a user (uh, uh), get its groups.
         THIS METHODS NOW SUPPORTS NESTED GROUPS ! :-)
@@ -180,6 +180,9 @@ class GRUFUserAtom(AccessControl.User.BasicUser, Implicit):
 
         This method is private and should remain so.
         """
+        if already_done is None:
+            already_done = []
+
         # List this user's roles. We consider that roles starting 
         # with GROUP_PREFIX are in fact groups, and thus are 
         # returned (prefixed).
@@ -380,11 +383,11 @@ class GRUFUserAtom(AccessControl.User.BasicUser, Implicit):
 
 
     security.declarePrivate("getProperty")
-    def getProperty(self, name, default = _marker):
+    def getProperty(self, name, default=_marker):
         """getProperty(self, name) => return property value or raise AttributeError
         """
         # Try to do an attribute lookup on the underlying user object
-        v = getattr(self.__underlying__, name, _marker)
+        v = getattr(self.__underlying__, name, default)
         if v is _marker:
             raise AttributeError, name
         return v
@@ -598,7 +601,7 @@ class GRUFUserAtom(AccessControl.User.BasicUser, Implicit):
 
         ret = '''<a href="%(href)s" alt="%(alt)s"><font color="%(color)s">%(name)s</font></a>''' % {
             "color": color,
-            "href": "%s/%s/manage_workspace" % (acl_users.absolute_url(), self.getId(), ),
+            "href": "%s/%s/manage_workspace?FORCE_USER=1" % (acl_users.absolute_url(), self.getId(), ),
             "name": self.getUserNameWithoutGroupPrefix(),
             "alt": "%s (%s)" % (self.getUserNameWithoutGroupPrefix(), kind, ),
             }
@@ -746,22 +749,64 @@ class GRUFGroup(GRUFUserAtom):
         """
         return self.getId()[len(GROUP_PREFIX):]
     
-    def _getMemberIds(self, users = 1, groups = 1, transitive = 1, ):
-        """Return the member ids (users and groups) of the atoms of this group"""
-        # Initial parameters
+    def _getLDAPMemberIds(self,):
+        """
+        _getLDAPMemberIds(self,) => Uses LDAPUserFolder to find
+        users in a group.
+        """
+        # Find the right source
         gruf = self.aq_parent
+        src = None
+        for src in gruf.listUserSources():
+            if not src.meta_type == "LDAPUserFolder":
+                continue
+        if src is None:
+            Log(LOG_DEBUG, "No LDAPUserFolder source found")
+            return []
+
+        # Find the group in LDAP
+        groups = src.getGroups()
+        groupid = self.getId()
+        grp = [ group for group in groups if group[0] == self.getId() ]
+        if not grp:
+            Log(LOG_DEBUG, "No such group ('%s') found." % (groupid,))
+            return []
+
+        # Return the grup member ids
+        userids = src.getGroupedUsers(grp)
+        Log(LOG_DEBUG, "We've found %d users belonging to the group '%s'" % (len(userids), grp), )
+        return userids
+    
+    def _getMemberIds(self, users = 1, groups = 1, transitive = 1, ):
+        """
+	Return the member ids (users and groups) of the atoms of this group.
+	Transitiveness attribute is ignored with LDAP (no nested groups with
+	LDAP anyway).
+	This method now uses a shortcut to fetch members of an LDAP group
+	(stored either within Zope or within your LDAP server)
+	"""
+        # Initial parameters.
+        # We fetch the users/groups list depending on what we search,
+        # and carefuly avoiding to use LDAP sources.
+        gruf = self.aq_parent
+        ldap_sources = []
+        lst = []
         if transitive:
             method = "getAllGroupIds"
         else:
             method = "getGroupIds"
-        if users and not groups:
-            lst = gruf.getPureUserIds()
-        elif groups and not users:
-            lst = gruf.getGroupIds()
-        else:
-            lst = gruf.getUserIds()
+        if users:
+            for src in gruf.listUserSources():
+                if src.meta_type == 'LDAPUserFolder':
+                    ldap_sources.append(src)
+                    continue # We'll fetch 'em later
+                lst.extend(src.getUserNames())
+        if groups:
+            lst.extend(gruf.getGroupIds())
 
-        # Extraction
+        # First extraction for regular user sources.
+        # This part is very very long, and the more users you have,
+        # the longer this method will be.
         groupid = self.getId()
         groups_mapping = {}
         for u in lst:
@@ -771,7 +816,24 @@ class GRUFGroup(GRUFUserAtom):
                 Log(LOG_WARNING, "Invalid user retreiving:", u)
             else:
                 groups_mapping[u] = getattr(usr, method)()
-        return [u for u in lst if groupid in groups_mapping[u]]
+        members = [u for u in lst if groupid in groups_mapping[u]]
+
+        # If we have LDAP sources, we fetch user-group mapping inside directly
+        groupid = self.getId()
+        for src in ldap_sources:
+            groups = src.getGroups()
+            grp = [ group for group in groups if group[0] == self.getId() ]
+            if not grp:
+                Log(LOG_DEBUG, "No such group ('%s') found." % (groupid,))
+                continue
+
+            # Return the grup member ids
+            userids = [ str(u) for u in src.getGroupedUsers(grp) ]
+            Log(LOG_DEBUG, "We've found %d users belonging to the group '%s'" % (len(userids), grp), )
+            members.extend(userids)
+
+        # Return the members we've found
+        return members
 
     security.declarePrivate("getMemberIds")
     def getMemberIds(self, transitive = 1, ):
