@@ -5,20 +5,27 @@
 ##############################################################################
 """ Basic usergroup tool.
 
-$Id: GroupsTool.py,v 1.32 2004/07/13 13:07:46 pjgrizel Exp $
+$Id: GroupsTool.py 14962 2005-12-16 13:27:49Z hannosch $
 """
 
 from Products.CMFCore.utils import UniqueObject
 from Products.CMFCore.utils import getToolByName
+from Products.CMFCore.utils import _checkPermission
 from OFS.SimpleItem import SimpleItem
 from Globals import InitializeClass, DTMLFile, MessageDialog
 from Acquisition import aq_base
 from AccessControl.User import nobody
 from AccessControl import ClassSecurityInfo
-from Products.CMFCore.CMFCorePermissions import View
-from Products.CMFCore.CMFCorePermissions import AccessContentsInformation
-from Products.CMFCore.CMFCorePermissions import ManagePortal
-from Products.CMFCore.CMFCorePermissions import ViewManagementScreens
+# BBB CMF < 1.5
+try:
+    from Products.CMFCore.permissions import ManagePortal
+    from Products.CMFCore.permissions import View
+    from Products.CMFCore.permissions import ViewManagementScreens
+except ImportError:
+    from Products.CMFCore.CMFCorePermissions import ManagePortal
+    from Products.CMFCore.CMFCorePermissions import View
+    from Products.CMFCore.CMFCorePermissions import ViewManagementScreens
+
 from GroupsToolPermissions import AddGroups
 from GroupsToolPermissions import ManageGroups
 from GroupsToolPermissions import DeleteGroups
@@ -28,8 +35,11 @@ from Products.CMFCore.ActionProviderBase import ActionProviderBase
 from interfaces.portal_groups import portal_groups as IGroupsTool
 from global_symbols import *
 
+# Optional feature-preview support
+import PloneFeaturePreview
 
-class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase):
+
+class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase, ):
     """ This tool accesses group data through a GRUF acl_users object.
 
     It can be replaced with something that groups member data in a
@@ -62,9 +72,9 @@ class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase):
                      },
                 ) + SimpleItem.manage_options)
 
-    #
-    #   ZMI methods
-    #
+    #                                                   #
+    #                   ZMI methods                     #
+    #                                                   #
     security.declareProtected(ViewManagementScreens, 'manage_overview')
     manage_overview = DTMLFile('dtml/explainGroupsTool', globals())     # unlike MembershipTool
     security.declareProtected(ViewManagementScreens, 'manage_config')
@@ -102,7 +112,7 @@ class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase):
 
     security.declareProtected(ViewGroups, 'getGroupsByUserId')
     def getGroupsByUserId(self, userid):
-        """Returns a list of the groups the user corresponding to 'userid' belongs to."""
+        """Return a list of the groups the user corresponding to 'userid' belongs to."""
         #log("getGroupsByUserId(%s)" % userid)
         user = self.acl_users.getUser(userid)
         #log("user '%s' is in groups %s" % (userid, user.getGroups()))
@@ -114,17 +124,17 @@ class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase):
 
     security.declareProtected(ViewGroups, 'listGroups')
     def listGroups(self):
-        """Returns a list of the available portal_groupdata-ish objects."""
-        return [self.wrapGroup(elt) for elt in self.acl_users.getGroups()]
+        """Return a list of the available portal_groupdata-ish objects."""
+        return [ self.wrapGroup(elt) for elt in self.acl_users.getGroups() ]
 
     security.declareProtected(ViewGroups, 'listGroupIds')
     def listGroupIds(self):
-        """Returns a list of the available groups' ids as entered (without group prefixes)."""
+        """Return a list of the available groups' ids as entered (without group prefixes)."""
         return self.acl_users.getGroupNames()
 
     security.declareProtected(ViewGroups, 'listGroupNames')
     def listGroupNames(self):
-        """Returns a list of the available groups' ids as entered (without group prefixes)."""
+        """Return a list of the available groups' ids as entered (without group prefixes)."""
         return self.acl_users.getGroupNames()
 
     security.declarePublic("isGroup")
@@ -137,16 +147,6 @@ class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase):
             return 1
         return 0
 
-##    security.declarePrivate('getPureUserNames')
-##    def getPureUserNames(self):
-##        """Get the usernames (ids) of only users. """
-##        return self.acl_users.getPureUserNames()
-
-##    security.declarePrivate('getPureUsers')
-##    def getPureUsers(self):
-##        """Get the actual (unwrapped) user objects of only users. """
-##        return self.acl_users.getPureUsers()
-
     security.declareProtected(View, 'searchForGroups')
     def searchForGroups(self, REQUEST = {}, **kw):
         """Return a list of groups meeting certain conditions. """
@@ -160,6 +160,8 @@ class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase):
         email = dict.get('email', None)
         roles = dict.get('roles', None)
         title = dict.get('title', None)
+        title_or_name = dict.get('title_or_name', None)
+        
         last_login_time = dict.get('last_login_time', None)
         #is_manager = self.checkPermission('Manage portal', self)
 
@@ -173,6 +175,8 @@ class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase):
             email = None
         if title:
             title = title.strip().lower()
+        if title_or_name:
+            title_or_name = title_or_name.strip().lower()
         if not title:
             title = None
 
@@ -199,6 +203,13 @@ class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase):
             if title:
                 if g.title.lower().find(title) == -1:
                     continue
+            if title_or_name:
+                # first search for title
+                if g.title.lower().find(title_or_name) == -1:
+                    # not found, now search for name
+                    if (g.getGroupName().lower().find(title_or_name) == -1) and (g.getGroupId().lower().find(title_or_name) == -1):
+                        continue
+                
             if last_login_time:
                 if g.last_login_time < last_login_time:
                     continue
@@ -219,7 +230,7 @@ class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase):
         self.getGroupById(id).setProperties(**kw)
 
     security.declareProtected(ManageGroups, 'editGroup')
-    def editGroup(self, id, roles = [], groups = [], *args, **kw):
+    def editGroup(self, id, roles = None, groups = None, *args, **kw):
         """Edit the given group with the supplied password, roles, and domains.
 
         Underlying user folder must support editing users via the usual Zope API.
@@ -326,8 +337,11 @@ class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase):
         if id and self.getGroupWorkspacesCreationFlag():
             if workspaces is None:
                 # add GroupWorkspaces folder
-
-                parent.invokeFactory(self.getGroupWorkspaceContainerType(), self.getGroupWorkspacesFolderId())
+                pt.constructContent(
+                    type_name = self.getGroupWorkspaceContainerType(),
+                    container = parent,
+                    id = self.getGroupWorkspacesFolderId(),
+                    )
                 workspaces = self.getGroupWorkspacesFolder()
                 workspaces.setTitle(self.getGroupWorkspacesFolderTitle())
                 workspaces.setDescription("Container for " + self.getGroupWorkspacesFolderId())
@@ -337,10 +351,14 @@ class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase):
                 portal_catalog = getToolByName( self, 'portal_catalog' )
                 portal_catalog.unindexObject(workspaces)     # unindex GroupWorkspaces folder
                 workspaces._setProperty('right_slots', (), 'lines')
-
-            if workspaces is not None and not hasattr(workspaces, id):
+                
+            if workspaces is not None and not hasattr(workspaces.aq_base, id):
                 # add workspace to GroupWorkspaces folder
-                workspaces.invokeFactory(self.getGroupWorkspaceType(), id)
+                pt.constructContent(
+                    type_name = self.getGroupWorkspaceType(),
+                    container = workspaces,
+                    id = id,
+                    )
                 space = self.getGroupareaFolder(id)
                 space.setTitle("%s workspace" % id)
                 space.setDescription("Container for objects shared by this group")
@@ -354,6 +372,13 @@ class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase):
                 else:
                     space.manage_delLocalRoles(space.users_with_local_role('Owner'))
                     self.setGroupOwnership(self.getGroupById(id), space)
+
+                # Hook to allow doing other things after grouparea creation.
+                notify_script = getattr(workspaces, 'notifyGroupAreaCreated', None)
+                if notify_script is not None:
+                    notify_script()
+
+                # Re-indexation
                 portal_catalog = getToolByName( self, 'portal_catalog' )
                 portal_catalog.reindexObject(space)
  
@@ -426,26 +451,13 @@ class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase):
         parent = self.aq_inner.aq_parent
         base = getattr(parent, 'aq_base', None)
         if hasattr(base, 'portal_groupdata'):
-##             # Apply any role mapping if we have it
-##             if hasattr(self, 'role_map'):
-##                 for portal_role in self.role_map.keys():
-##                     if (self.role_map.get(portal_role) in u.roles and
-##                             portal_role not in u.roles):
-##                         u.roles.append(portal_role)
-
             # Get portal_groupdata to do the wrapping.
+            Log(LOG_DEBUG, "parent", parent)
             gd = getToolByName(parent, 'portal_groupdata')
+            Log(LOG_DEBUG, "group data", gd)
             try:
                 #log("wrapping group %s" % g)
                 portal_group = gd.wrapGroup(g)
-
-                # Check for the member area creation flag and
-                # take appropriate (non-) action
-
-                # DISABLED: do it upon group creation
-                #if self.getGroupWorkspacesCreationFlag():
-                #    self.createGrouparea(portal_group.getGroupName())
-
                 return portal_group
 
             except:
