@@ -5,13 +5,14 @@
 ##############################################################################
 """ Basic usergroup tool.
 
-$Id: GroupsToolPermissions.py,v 1.5 2004/05/04 21:48:46 dreamcatcher Exp $
+$Id: GroupsToolPermissions.py 14962 2005-12-16 13:27:49Z hannosch $
 """
 
-from Products.CMFCore.CMFCorePermissions import setDefaultRoles
-
-#AddRisaModuleEditor = 'Add RISA Module Editor'
-#setDefaultRoles(AddRisaModuleEditor, ('Manager', 'Owner', 'Member', 'Anonymous'))
+# BBB CMF < 1.5
+try:
+    from Products.CMFCore.permissions import *
+except ImportError:
+    from Products.CMFCore.CMFCorePermissions import *
 
 AddGroups = 'Add Groups'
 setDefaultRoles(AddGroups, ('Manager',))
