@@ -30,7 +30,7 @@ ZopeTestCase.close(app)
 
 # Start the web server
 host, port = ZopeTestCase.utils.startZServer(4)
-base = 'http://%s:%d/%s' %(host, port, ZopeTestCase._folder_name)
+base = 'http://%s:%d/%s' %(host, port, ZopeTestCase.folder_name)
 
 
 # Get global vars
@@ -118,6 +118,7 @@ class TestGroupUserFolder(GRUFTestCase.GRUFTestCase):
             password = 'secret',
             roles = ('userrole', ),
             groups = ('gtest', ),
+            domains = (),
             )
 
         # Check if the user has the right roles
@@ -431,7 +432,41 @@ class TestGroupUserFolder(GRUFTestCase.GRUFTestCase):
             self.failUnless(u in un, "Invalid users list: '%s' is not in acl_users." % (u,))
         for u in un:
             self.failUnless(u in users, "Invalid users list: '%s' is in acl_users but shouldn't be there." % (u,))
-        
+
+    def test16user_group_same_name(self):
+        """getLocalRolesForDisplay should know whether the local role on an object
+        belongs to a group or a user even if the two share a name.
+        """
+        # So we are allowed to call getLocalRolesForDisplay
+        self.setPermissions([Permissions.manage_properties])
+        self.gruf.userFolderAddGroup('foo', ('r1', ))
+        self.gruf.userFolderAddUser('foo', 'secret', (), (), ('foo', ), )
+        lr = self.gruf_folder.lr
+        lr.manage_addProduct['OFSP'].manage_addFolder("foo_lr")
+        foo_lr = lr.foo_lr
+        foo_lr.manage_addLocalRoles("foo", ("r3", ))
+        roles_map = self.gruf.getLocalRolesForDisplay(foo_lr)
+        self.failUnless(('foo',('r3',),'user','foo') in roles_map)
+        foo_lr.manage_addLocalRoles("group_foo", ("r2", ))
+        roles_map = self.gruf.getLocalRolesForDisplay(foo_lr)
+        self.failUnless(('foo',('r2',),'group','group_foo') in roles_map)
+
+    def test17AnonymousGetLocalRolesForDisplay(self):
+        # getLocalRolesForDisplay should raise Unauthorized for Anonymous
+        self.logout()
+        self.assertRaises(Unauthorized, self.gruf.getLocalRolesForDisplay, self.gruf_folder)
+
+    def test18ManagePropertiesInformationGetLocalRolesForDisplay(self):
+        # getLocalRolesForDisplay should raise Unauthorized for users
+        # without Manage properties permission
+        self.assertRaises(Unauthorized, self.gruf.getLocalRolesForDisplay, self.gruf_folder)
+
+    def test19ManagePropertiesInformationGetLocalRolesForDisplay(self):
+        # getLocalRolesForDisplay should work for users with
+        # Manage properties permission
+        self.setPermissions([Permissions.manage_properties])
+        self.gruf.getLocalRolesForDisplay(self.gruf_folder)
+
 
 def _mergedLocalRoles(object):
     """Returns a merging of object and its ancestors'
@@ -470,8 +505,7 @@ class TestGroupUserFolderCopy(TestGroupUserFolder):
 
         # Now copy/paste a re-build the security context in another folder
         self._setupUser()
-        self._setRoles(['Manager', ], )
-        self._login()
+        self.setRoles(['Manager'])
         self.folder.manage_addProduct['OFSP'].manage_addFolder('gruf_folder2')
         folder2 = self.folder.gruf_folder2
 
@@ -479,6 +513,8 @@ class TestGroupUserFolderCopy(TestGroupUserFolder):
         copy = self.gruf_folder.manage_copyObjects(ids = ['acl_users',],)
         folder2.manage_pasteObjects(cb_copy_data = copy)
 
+        # Back to normal
+        self.setRoles(ZopeTestCase.user_role)
 
 
 if __name__ == '__main__':
