@@ -4,19 +4,18 @@
 #                                                       #
 # (c)2002+ Ingeniweb                                    #
 
-
 import os, sys
 if __name__ == '__main__':
     execfile(os.path.join(sys.path[0], 'framework.py'))
 
-
-
 # Load fixture
 from Testing import ZopeTestCase
 
 # Permissions / security
-from AccessControl.Permissions import access_contents_information, view, add_documents_images_and_files, change_images_and_files, view_management_screens
-from AccessControl.SecurityManagement import newSecurityManager, noSecurityManager, getSecurityManager
+from AccessControl.Permissions import access_contents_information, view, \
+     add_documents_images_and_files, change_images_and_files, view_management_screens
+from AccessControl.SecurityManagement import newSecurityManager, \
+     noSecurityManager, getSecurityManager
 from AccessControl import Unauthorized
 from AccessControl.User import UnrestrictedUser
 
@@ -27,10 +26,7 @@ import string
 app = ZopeTestCase.app()
 ZopeTestCase.utils.setupSiteErrorLog(app)
 ZopeTestCase.close(app)
-
     
-# Get global vars
-#from Products.GroupUserFolder.global_symbols import *
 from Products.GroupUserFolder.interfaces import IUserFolder
 from Products.GroupUserFolder import GroupUserFolder
 from Interface import Verify
@@ -42,10 +38,8 @@ import GRUFTestCase
 import testInterface
 from Log import *
 
-
 class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterface):
 
-
     klasses = (        # tell which classes to check
         GroupUserFolder.GroupUserFolder,
         )
@@ -60,7 +54,6 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
     #                                                   #
     #                  GRUF API testing                 #
     #                                                   #
-
         
     def test_getUserNames(self):
         un = self.gruf.getUserNames()
@@ -78,7 +71,6 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
         for u in un:
             self.failUnless(u in users, "Invalid users list: '%s' is in acl_users but shouldn't be there." % (u,))
 
-
     def test_getUserIds(self):
         un = self.gruf.getUserIds()
         users = [
@@ -111,6 +103,9 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
         self.failUnless(grp.isGroup())
         self.failUnless(grp.getId() == "group_g1")
 
+    def test_hasUsers(self):
+        self.failUnlessEqual(self.gruf.hasUsers(), 1, "GRUF should always return 1 on hasUsers but didn't.")
+
     def test_getUsers(self):
         objects = self.gruf.getUsers()
         un = map(lambda x: x.getId(), objects)
@@ -137,9 +132,8 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
         self.failUnless(self.gruf.getUserById("g1", default = None) is None)
 
         # check exception raising & default values
-        try: self.gruf.getUserById("ZORGLUB")
-        except ValueError: pass
-        else: raise "AssertionError", "Should raise"
+        ret = self.gruf.getUserById("ZORGLUB")
+        self.failUnlessEqual(ret, None, "getUserById should return None")
         self.failUnless(self.gruf.getUserById("ZORGLUB", default = "bla") == "bla")
 
     def test_getUserByName(self):
@@ -151,12 +145,10 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
         self.failUnless(self.gruf.getUserByName("group_g1", None).getId() == "group_g1")
 
         # Check exception raising
-        try: self.gruf.getUserByName("ZORGLUB")
-        except ValueError: pass
-        else: raise "AssertionError", "Should raise"
+        ret = self.gruf.getUserByName("ZORGLUB")
+        self.failUnlessEqual(ret, None, "getUserByName should return None")
         self.failUnless(self.gruf.getUserByName("ZORGLUB", default = "bla") == "bla")
 
-
     # User access
 
     def test_getPureUserNames(self):
@@ -206,7 +198,6 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
         for u in un:
             self.failUnless(u in users, "Invalid users list: '%s' is in acl_users but shouldn't be there." % (u,))
 
-
     def test_getPureUser(self,):
         u = self.gruf.getPureUser("u1")
         self.failUnless(u)
@@ -297,9 +288,10 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
         self.failUnless(grp is None)
 
         # Check raise if user/group not found
-        try: self.gruf.getGroupById("ZORGLUB")
-        except ValueError: pass
-        else: raise "AssertionError", "Should raise"
+        self.failUnlessEqual(
+            self.gruf.getGroupById("ZORGLUB"),
+            None,
+            )
         self.failUnless(self.gruf.getGroupById("ZORGLUB", default = "bla") == "bla")
 
     def test_getGroupByName(self):
@@ -315,12 +307,12 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
         self.failUnless(self.gruf.getGroupByName("u1", default = None) is None)
 
         # Check raise if user/group not found
-        try: self.gruf.getGroupByName("ZORGLUB")
-        except ValueError: pass
-        else: raise "AssertionError", "Should raise"
+        self.failUnlessEqual(
+            self.gruf.getGroupByName("ZORGLUB"),
+            None,
+            )
         self.failUnless(self.gruf.getGroupByName("ZORGLUB", default = "bla") == "bla")
 
-
     # Mutators
 
     def test_userFolderAddUser(self):
@@ -329,6 +321,7 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
             password = "secret",
             roles = [],
             groups = [],
+            domains = (),
             )
         self.failUnless(self.gruf.getUser("created_user"))
         self.gruf.userFolderAddUser(
@@ -336,6 +329,7 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
             password = "secret",
             roles = [],
             groups = [],
+            domains = (),
             )
         self.failUnless(self.gruf.getUser("group_test_prefix"))
         self.failIf(self.gruf.getUser("group_test_prefix").isGroup())
@@ -346,14 +340,29 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
             password = "secret2",
             roles = ["r1", ],
             groups = ["g1", ],
+            domains = (),
             )
         self.compareRoles(None, "u1", ['r1',], )
 
+    def test_userFolderUpdateUser(self):
+        self.gruf.userFolderUpdateUser(
+            name = "u5",
+            roles = ["r2", ],
+            )
+        self.compareRoles(None, "u5", ['r1', 'r2',], )
+        self.compareGroups("u5", ['g2', 'g3'], )
+        self.gruf.userFolderUpdateUser(
+            name = "u6",
+            roles = None,
+            )
+        self.compareRoles(None, "u6", ['r1', 'r2', ], )
+
     def test_userFolderDelUsers(self):
         self.gruf.userFolderAddUser(
             name = "created_user",
             password = "secret",
             roles = [],
+            domains = (),
             groups = [],
             )
         self.gruf.userFolderDelUsers(['created_user', ])
@@ -402,6 +411,32 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
             "g2" in self.gruf.getGroupByName("created_group").getAllGroupNames(),
             self.gruf.getGroupByName("created_group").getAllGroupNames(),
             )
+        
+    def test_userFolderUpdateGroup(self):
+        self.gruf.userFolderAddGroup(
+            name = "created_group",
+            roles = [],
+            groups = [],
+            )
+        self.gruf.userFolderUpdateGroup(
+            name = "created_group",
+            roles = ["r1", ],
+            groups = ["group_g1", ],
+            )
+        self.compareRoles(None, "created_group", ['r1',], )
+        self.failUnless(
+            "g1" in self.gruf.getGroupByName("created_group").getAllGroupNames(),
+            self.gruf.getGroupByName("created_group").getAllGroupNames(),
+            )
+        self.gruf.userFolderUpdateGroup(
+            name = "created_group",
+            roles = ["r1", ],
+            groups = None,
+            )
+        self.failUnless(
+            "g1" in self.gruf.getGroupByName("created_group").getAllGroupNames(),
+            self.gruf.getGroupByName("created_group").getAllGroupNames(),
+            )
 
     def test_userFolderDelGroups(self):
         self.gruf.userFolderAddGroup(
@@ -412,7 +447,6 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
         self.gruf.userFolderDelGroups(['created_group', ])
         self.failUnless(self.gruf.getGroup("created_group") is None)
 
-
     # User mutation
 
     def test_userSetRoles(self):
@@ -478,6 +512,8 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
         self.gruf.userFolderAddUser(
             name = "created_user",
             password = "secret",
+            domains = (),
+            roles = (),
             groups = [],
             )
         self.gruf.userSetGroups("created_user", ["g1", "g2", ], )
@@ -491,8 +527,13 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
             name = "created_user",
             password = "secret",
             groups = ["g2", ],
+            roles = (),
+            domains = (),
+            )
+        self.gruf.userAddGroup(
+            "created_user",
+            "g1",
             )
-        self.gruf.userAddGroup("created_user", "g1", )
         self.compareGroups("created_user", ["g1", "g2", ], )
 
     def test_userRemoveGroup(self):
@@ -502,11 +543,12 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
             name = "created_user",
             password = "secret",
             groups = ["g2", "g1", ],
+            domains = (),
+            roles = (),
             )
         self.gruf.userRemoveGroup("created_user", "g1", )
         self.compareGroups("created_user", ["g2", ], )
 
-
     # Searching
 
     def test_searchUsersByAttribute(self,):
@@ -708,7 +750,6 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
         self.failUnless(
             "r9" not in self.gruf.getRolesOfUser("u4")
             )
-        
 
     # Groups support
     def test_setMembers(self):
@@ -733,7 +774,6 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
         users.sort()
         self.failUnless(users == should_be, (users, should_be))
 
-
     def test_getUserMemberIds(self,):
         """This tests nested groups"""
         should_be = [
@@ -761,7 +801,6 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
         users.sort()
         self.failUnless(users == should_be, (users, should_be, ))
 
-
     def test_addMember(self):
         """Add a member to a group
         """
@@ -769,7 +808,6 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
         self.gruf.addMember("ng3", "u1")
         self.failUnless("u1" in self.gruf.getMemberIds("ng3"))
 
-
     def test_removeMember(self):
         """Remove a member from a group
         """    
@@ -778,7 +816,6 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
         self.failUnless("u1" in self.gruf.getMemberIds("ng3"))
         self.gruf.removeMember("ng3", "u1")
         self.failUnless("u1" not in self.gruf.getMemberIds("ng3"))
-        
 
     def test_hasMember(self,):
         self.failUnless(not self.gruf.hasMember("ng3", "u1"))
@@ -789,7 +826,6 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
         self.gruf.removeMember("ng3", "u1")
         self.failUnless(not self.gruf.hasMember("ng3", "u1"))
         self.failUnless(not self.gruf.hasMember("group_ng3", "u1"))
-        
 
     # Misc
     def test_getRealId(self,):
@@ -799,9 +835,7 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
         u = self.gruf.getUser("u1")
         self.failUnless(u.getRealId() == "u1")
 
-
     # Local roles management
-
     def test_acquireLocalRoles(self,):
         """
         We block LR acquisition on sublr2.
@@ -825,7 +859,6 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
         self.failUnless(self.compareRoles(self.subsublr2, "u3", ("r1", "r2", )))
         self.failUnless(self.compareRoles(self.subsublr2, "u6", ("r1", "r2", )))
 
-
     def test_isLocalRoleAcquired(self,):
         self.gruf._acquireLocalRoles(self.sublr2, 0)
         self.failUnless(not self.gruf.isLocalRoleAcquired(self.sublr2))
@@ -840,7 +873,6 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
         self.failUnless(self.gruf.isLocalRoleAcquired(self.sublr2))
         self.failUnless(self.gruf.isLocalRoleAcquired(self.subsublr2))
 
-
     # Audit checks
 
     def test_getAllLocalRoles(self):
