@@ -10,7 +10,8 @@ if __name__ == '__main__':
 
 # Load fixture
 from Testing import ZopeTestCase
-from Products.CMFPlone.tests import PloneTestCase
+from Products.PloneTestCase import PloneTestCase
+PloneTestCase.setupPloneSite()
 
 # Permissions / security
 from AccessControl.Permissions import access_contents_information, view, \
@@ -45,6 +46,8 @@ from Log import *
 class GroupTestCase(PloneTestCase.PloneTestCase, ):
     
     def afterSetUp(self):
+        self.setRoles(['Manager'])
+
         # Basic assignements
         self.membership = self.portal.portal_membership
         self.gruf = self.portal.acl_users
@@ -89,7 +92,7 @@ class TestGroupsTool(GroupTestCase, testInterface.TestInterface):
         ActionProviderBase.__implements__,
     )
 
-    def test_isGroup(self,):
+    def test_isGroup(self,):        
         g1 = self.groups.getGroupById("g1")
         g1.addMember("g2")
         ngroups = 0
@@ -447,6 +450,43 @@ class TestGroupData(GroupTestCase, testInterface.TestInterface):
             )
 
 
+from AccessControl import Unauthorized
+from AccessControl import Permissions
+from Testing.ZopeTestCase import user_name
+
+class TestMethodProtection(PloneTestCase.PloneTestCase):
+    # GroupData has wrong security declarations
+
+    def afterSetUp(self):
+        self.groups = self.portal.portal_groups
+        self.groups.groupWorkspacesCreationFlag = 0
+        self.groups.addGroup('foo')
+        self.groupdata = self.groups.getGroupById('foo')
+
+    def testAnonAddMember(self):
+        self.logout()
+        self.assertRaises(Unauthorized, self.groupdata.addMember, user_name)
+
+    def testAnonRemoveMember(self):
+        self.logout()
+        self.assertRaises(Unauthorized, self.groupdata.removeMember, user_name)
+
+    def testMemberAddMember(self):
+        self.assertRaises(Unauthorized, self.groupdata.addMember, user_name)
+
+    def testMemberRemoveMember(self):
+        self.assertRaises(Unauthorized, self.groupdata.removeMember, user_name)
+
+    def testManagerAddMember(self):
+        self.setPermissions([Permissions.manage_users])
+        self.groupdata.addMember(user_name)
+
+    def testManagerRemoveMember(self):
+        self.setPermissions([Permissions.manage_users])
+        self.groupdata.addMember(user_name)
+        self.groupdata.removeMember(user_name)
+
+
 if __name__ == '__main__':
     framework(descriptions=1, verbosity=1)
 else:
@@ -456,5 +496,6 @@ else:
         suite.addTest(unittest.makeSuite(TestGroupsTool))
         suite.addTest(unittest.makeSuite(TestGroupDataTool))
         suite.addTest(unittest.makeSuite(TestGroupData))
+        suite.addTest(unittest.makeSuite(TestMethodProtection))
         return suite
 
